# -*- coding: utf-8 -*-

# :copyright: (c) 2011 - 2012 by Arezqui Belaid.
# :license: MPL 2.0, see COPYING for more details.

VERSION = (0, 1, 1, "")
__version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
__author__ = "Arezqui Belaid"
__contact__ = "info@star2billing.com"
__homepage__ = "http://www.star2billing.org"
__docformat__ = "restructuredtext"
